@@ -259,7 +259,7 @@ def parse_config(filename, encoding='utf8'):
                 'Could not read the data from %r, do you have the correct '
                 'permissions and is it encoded as UTF8?'%filename
             )
-    parse_config_string(data, filename, encoding)
+    return parse_config_string(data, filename, encoding)
 
 def parse_config_string(data, filename=None, encoding='utf8'):
     conf = {}
